@@ -73,7 +73,20 @@ class TemporalAsset(proto.Message):
     """
 
     class PriorAssetState(proto.Enum):
-        r"""State of prior asset."""
+        r"""State of prior asset.
+
+        Values:
+            PRIOR_ASSET_STATE_UNSPECIFIED (0):
+                prior_asset is not applicable for the current asset.
+            PRESENT (1):
+                prior_asset is populated correctly.
+            INVALID (2):
+                Failed to set prior_asset.
+            DOES_NOT_EXIST (3):
+                Current asset is the first known state.
+            DELETED (4):
+                prior_asset is a deletion.
+        """
         PRIOR_ASSET_STATE_UNSPECIFIED = 0
         PRESENT = 1
         INVALID = 2
@@ -136,8 +149,8 @@ class Asset(proto.Message):
     hierarchy <https://cloud.google.com/resource-manager/docs/cloud-platform-resource-hierarchy>`__,
     a resource outside the Google Cloud resource hierarchy (such as
     Google Kubernetes Engine clusters and objects), or a policy (e.g.
-    Cloud IAM policy), or a relationship (e.g. an
-    INSTANCE_TO_INSTANCEGROUP relationship). See `Supported asset
+    IAM policy), or a relationship (e.g. an INSTANCE_TO_INSTANCEGROUP
+    relationship). See `Supported asset
     types <https://cloud.google.com/asset-inventory/docs/supported-asset-types>`__
     for more information.
 
@@ -169,15 +182,14 @@ class Asset(proto.Message):
         resource (google.cloud.asset_v1.types.Resource):
             A representation of the resource.
         iam_policy (google.iam.v1.policy_pb2.Policy):
-            A representation of the Cloud IAM policy set on a Google
-            Cloud resource. There can be a maximum of one Cloud IAM
-            policy set on any given resource. In addition, Cloud IAM
-            policies inherit their granted access scope from any
-            policies set on parent resources in the resource hierarchy.
-            Therefore, the effectively policy is the union of both the
-            policy set on this resource and each policy set on all of
-            the resource's ancestry resource levels in the hierarchy.
-            See `this
+            A representation of the IAM policy set on a Google Cloud
+            resource. There can be a maximum of one IAM policy set on
+            any given resource. In addition, IAM policies inherit their
+            granted access scope from any policies set on parent
+            resources in the resource hierarchy. Therefore, the
+            effectively policy is the union of both the policy set on
+            this resource and each policy set on all of the resource's
+            ancestry resource levels in the hierarchy. See `this
             topic <https://cloud.google.com/iam/help/allow-policies/inheritance>`__
             for more information.
         org_policy (MutableSequence[google.cloud.orgpolicy.v1.orgpolicy_pb2.Policy]):
@@ -326,7 +338,7 @@ class Resource(proto.Message):
             for more information.
 
             For Google Cloud assets, this value is the parent resource
-            defined in the `Cloud IAM policy
+            defined in the `IAM policy
             hierarchy <https://cloud.google.com/iam/docs/overview#policy_hierarchy>`__.
             Example:
             ``//cloudresourcemanager.googleapis.com/projects/my_project_123``
@@ -445,7 +457,7 @@ class RelatedAsset(proto.Message):
     hierarchy <https://cloud.google.com/resource-manager/docs/cloud-platform-resource-hierarchy>`__,
     a resource outside the Google Cloud resource hierarchy (such as
     Google Kubernetes Engine clusters and objects), or a policy (e.g.
-    Cloud IAM policy). See `Supported asset
+    IAM policy). See `Supported asset
     types <https://cloud.google.com/asset-inventory/docs/supported-asset-types>`__
     for more information.
 
@@ -581,7 +593,7 @@ class ResourceSearchResult(proto.Message):
             -  Use a free text query. Example: ``us-west*``
         labels (MutableMapping[str, str]):
             Labels associated with this resource. See `Labelling and
-            grouping GCP
+            grouping Google Cloud
             resources <https://cloud.google.com/blog/products/gcp/labelling-and-grouping-your-google-cloud-platform-resources>`__
             for more information. This field is available only when the
             resource's Protobuf contains it.
@@ -599,8 +611,8 @@ class ResourceSearchResult(proto.Message):
             -  Use a free text query. Example: ``prod``
         network_tags (MutableSequence[str]):
             Network tags associated with this resource. Like labels,
-            network tags are a type of annotations used to group GCP
-            resources. See `Labelling GCP
+            network tags are a type of annotations used to group Google
+            Cloud resources. See `Labelling Google Cloud
             resources <https://cloud.google.com/blog/products/gcp/labelling-and-grouping-your-google-cloud-platform-resources>`__
             for more information. This field is available only when the
             resource's Protobuf contains it.
@@ -618,9 +630,9 @@ class ResourceSearchResult(proto.Message):
 
             This field only presents for the purpose of backward
             compatibility. Please use the ``kms_keys`` field to retrieve
-            KMS key information. This field is available only when the
-            resource's Protobuf contains it and will only be populated
-            for `these resource
+            Cloud KMS key information. This field is available only when
+            the resource's Protobuf contains it and will only be
+            populated for `these resource
             types <https://cloud.google.com/asset-inventory/docs/legacy-field-names#resource_types_with_the_to_be_deprecated_kmskey_field>`__
             for backward compatible purposes.
 
@@ -683,9 +695,9 @@ class ResourceSearchResult(proto.Message):
             RUNNING, STOPPING, SUSPENDING, SUSPENDED, REPAIRING, and
             TERMINATED. See ``status`` definition in `API
             Reference <https://cloud.google.com/compute/docs/reference/rest/v1/instances>`__.
-            If the resource is a project provided by Cloud Resource
-            Manager, its state will include LIFECYCLE_STATE_UNSPECIFIED,
-            ACTIVE, DELETE_REQUESTED and DELETE_IN_PROGRESS. See
+            If the resource is a project provided by Resource Manager,
+            its state will include LIFECYCLE_STATE_UNSPECIFIED, ACTIVE,
+            DELETE_REQUESTED and DELETE_IN_PROGRESS. See
             ``lifecycleState`` definition in `API
             Reference <https://cloud.google.com/resource-manager/reference/rest/v1/projects>`__.
 
@@ -699,15 +711,17 @@ class ResourceSearchResult(proto.Message):
             Examples: ``projectId`` for Project, ``dnsName`` for DNS
             ManagedZone. This field contains a subset of the resource
             metadata fields that are returned by the List or Get APIs
-            provided by the corresponding GCP service (e.g., Compute
-            Engine). see `API references and supported searchable
+            provided by the corresponding Google Cloud service (e.g.,
+            Compute Engine). see `API references and supported
+            searchable
             attributes <https://cloud.google.com/asset-inventory/docs/supported-asset-types#searchable_asset_types>`__
             to see which fields are included.
 
             You can search values of these fields through free text
             search. However, you should not consume the field
             programically as the field names and values may change as
-            the GCP service updates to a new incompatible API version.
+            the Google Cloud service updates to a new incompatible API
+            version.
 
             To search against the ``additional_attributes``:
 
@@ -1040,12 +1054,12 @@ class IamPolicySearchResult(proto.Message):
 
             -  specify the ``asset_types`` field in your search request.
         project (str):
-            The project that the associated GCP resource belongs to, in
-            the form of projects/{PROJECT_NUMBER}. If an IAM policy is
-            set on a resource (like VM instance, Cloud Storage bucket),
-            the project field will indicate the project that contains
-            the resource. If an IAM policy is set on a folder or
-            orgnization, this field will be empty.
+            The project that the associated Google Cloud resource
+            belongs to, in the form of projects/{PROJECT_NUMBER}. If an
+            IAM policy is set on a resource (like VM instance, Cloud
+            Storage bucket), the project field will indicate the project
+            that contains the resource. If an IAM policy is set on a
+            folder or orgnization, this field will be empty.
 
             To search against the ``project``:
 
@@ -1209,7 +1223,20 @@ class ConditionEvaluation(proto.Message):
     """
 
     class EvaluationValue(proto.Enum):
-        r"""Value of this expression."""
+        r"""Value of this expression.
+
+        Values:
+            EVALUATION_VALUE_UNSPECIFIED (0):
+                Reserved for future use.
+            TRUE (1):
+                The evaluation result is ``true``.
+            FALSE (2):
+                The evaluation result is ``false``.
+            CONDITIONAL (3):
+                The evaluation result is ``conditional`` when the condition
+                expression contains variables that are either missing input
+                values or have not been supported by Analyzer yet.
+        """
         EVALUATION_VALUE_UNSPECIFIED = 0
         TRUE = 1
         FALSE = 2
@@ -1234,7 +1261,7 @@ class IamPolicyAnalysisResult(proto.Message):
             [iam_binding][google.cloud.asset.v1.IamPolicyAnalysisResult.iam_binding]
             policy attaches.
         iam_binding (google.iam.v1.policy_pb2.Binding):
-            The Cloud IAM policy binding under analysis.
+            The IAM policy binding under analysis.
         access_control_lists (MutableSequence[google.cloud.asset_v1.types.IamPolicyAnalysisResult.AccessControlList]):
             The access control lists derived from the
             [iam_binding][google.cloud.asset.v1.IamPolicyAnalysisResult.iam_binding]
