@@ -40,7 +40,16 @@ __protobuf__ = proto.module(
 
 
 class ContentType(proto.Enum):
-    r"""Asset content type."""
+    r"""Asset content type.
+
+    Values:
+        CONTENT_TYPE_UNSPECIFIED (0):
+            Unspecified content type.
+        RESOURCE (1):
+            Resource metadata.
+        IAM_POLICY (2):
+            The actual IAM policy set on a resource.
+    """
     CONTENT_TYPE_UNSPECIFIED = 0
     RESOURCE = 1
     IAM_POLICY = 2
