@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -211,14 +211,13 @@ class AssetServiceAsyncClient:
         [IamPolicyAnalysisResult][google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult]
         matching the request.
 
-
         .. code-block:: python
 
             from google.cloud import asset_v1p4beta1
 
-            def sample_analyze_iam_policy():
+            async def sample_analyze_iam_policy():
                 # Create a client
-                client = asset_v1p4beta1.AssetServiceClient()
+                client = asset_v1p4beta1.AssetServiceAsyncClient()
 
                 # Initialize request argument(s)
                 analysis_query = asset_v1p4beta1.IamPolicyAnalysisQuery()
@@ -229,7 +228,7 @@ class AssetServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.analyze_iam_policy(request=request)
+                response = await client.analyze_iam_policy(request=request)
 
                 # Handle the response
                 print(response)
@@ -279,7 +278,12 @@ class AssetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -298,14 +302,13 @@ class AssetServiceAsyncClient:
         allowing you to keep track of the export. The metadata contains
         the request to help callers to map responses to requests.
 
-
         .. code-block:: python
 
             from google.cloud import asset_v1p4beta1
 
-            def sample_export_iam_policy_analysis():
+            async def sample_export_iam_policy_analysis():
                 # Create a client
-                client = asset_v1p4beta1.AssetServiceClient()
+                client = asset_v1p4beta1.AssetServiceAsyncClient()
 
                 # Initialize request argument(s)
                 analysis_query = asset_v1p4beta1.IamPolicyAnalysisQuery()
@@ -324,7 +327,7 @@ class AssetServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -369,7 +372,12 @@ class AssetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -391,7 +399,9 @@ class AssetServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-asset",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-asset",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
